package sgc.portal.cw.cw0901.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw0901.dto.CW09010001USearch;
import sgc.portal.cw.cw0901.model.CW09010001U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CW09010001UMapper {
	
	//주간보고작성  조회
	List<EasyHashMap<String, Object>> selectZehrWeekWorkList(CW09010001USearch search);
	
	//날짜  조회
	List<EasyHashMap<String, Object>> selectZehrWeekWorkMonthList(CW09010001USearch search);
	
	//첨부파일  조회
	EasyHashMap<String, Object> selectZehrWeekWorkAtchfileIdMap(CW09010001USearch search);
	List<EasyHashMap<String, Object>> selectZehrWeekWorkAtchfileIdList(CW09010001USearch search);

	//주간보고작성  수정삭체추가
	void insertZehrWeekWork(CW09010001U cW09010001U);
	void deleteZehrWeekWork(CW09010001U cW09010001U);
	void updateZehrWeekWork(CW09010001U cW09010001U);

	void insertZehrWeekWorkRpt(CW09010001U cW09010001U);
	void deleteZehrWeekWorkRpt(CW09010001U cW09010001U);
	void updateZehrWeekWorkRpt(CW09010001U cW09010001U);
	
	int selectZehrWeekWorkRptCount(CW09010001U cW09010001U);
	String selectworkBasedateTo(CW09010001U cW09010001U);
	void updateZehrWeekWorkAtchfileId(CW09010001U cW09010001U);
	
	int selectZehrWeekWorkAtchfileIdCount(CW09010001U cW09010001U);
	
	List<EasyHashMap<String, Object>> selectZehrWeekWorkDeptCdList(CW09010001USearch search);
	
	String selectDeptChk(CW09010001USearch search);
}
